/*
{
 "CREDIT" : "Fabrizio Poce",
  "CATEGORIES" : [
    "Manipulator"
  ],
  "DESCRIPTION" : "A kaleidoscope effect",
  "ISFVSN" : "2",
  "INPUTS" : [
    {
      "NAME" : "inputImage",
      "TYPE" : "image"
    },
    {
      "NAME" : "scaleX",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 10,
      "DEFAULT" : 1
    },
    {
      "NAME" : "scaleY",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 10,
      "DEFAULT" : 1
    },
    {
      "NAME" : "offsetX",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 1,
      "DEFAULT" : 0.5
    },
    {
      "NAME" : "offsetY",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 1,
      "DEFAULT" : 0.5
    },
    {
      "NAME" : "originX",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 1,
      "DEFAULT" : 0.5
    },
    {
      "NAME" : "originY",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 1,
      "DEFAULT" : 0.5
    },
    {
      "NAME" : "division",
      "TYPE" : "float",
      "MIN" : 0,
      "MAX" : 10,
      "DEFAULT" : 0
    },
  ]
 }
*/

#define PI 3.1415926

void main() {
    vec2 loc = isf_FragNormCoord.xy;

    vec2 scale = vec2(scaleX * 2, scaleY * 2);
    vec2 offset = vec2(offsetX * 2 - 1, offsetY * 2 - 1);
    vec2 origin = vec2(originX * 2 - 1, originY * 2 - 1);
    float div = 2.0 * (1.0 + division);

    vec2 point = abs(mod(loc * scale - scale * 0.5 + origin,1.));
    vec2 dt = point-0.5;
    float radius = sqrt(dot(dt,dt)); //hypot
    float theta = atan(dt.y,dt.x)+PI;
    float phi = 2.*PI/div;

    float modtheta = mod(abs(theta),phi*2.);
    float foldtheta = phi-abs(modtheta-phi);

    vec2 no = vec2(-cos(foldtheta)*radius, -sin(foldtheta)*radius);
    no = (no+0.5);
    vec2 off = abs(no+offset);
    vec2 modoff = mod(off,2.);
    vec2 fold = 1-abs(modoff-1);

    gl_FragColor = IMG_NORM_PIXEL(inputImage,fold);
}
